@@ -6,6 +6,14 @@ from serverD.conf import *
 
 file_path = os.path.abspath(os.path.dirname(__file__))
 
+server_base_data = {
+
+    "serverPut": "{user} {host} {pwd} {port} {locPath} {serPath}",
+    "serverGet": "{user} {host} {pwd} {port} {locPath} {serPath}",
+    "serverLogin": "{user} {host} {pwd} {port}",
+    "serverTbj": "{user} {host} {pwd} {port} {pem}",
+
+}
 
 class ServerD:
 
